diff -ru asterisk-1.4.0-beta2/funcs/func_enum.c asterisk-1.4.0-beta2-simple/funcs/func_enum.c
--- asterisk-1.4.0-beta2/funcs/func_enum.c	2006-08-21 04:11:39.000000000 +0200
+++ asterisk-1.4.0-beta2-simple/funcs/func_enum.c	2006-10-12 17:26:34.000000000 +0200
@@ -65,6 +65,7 @@
 	char dest[256] = "", tmp[2] = "", num[AST_MAX_EXTENSION] = "";
 	struct ast_module_user *u;
 	char *s, *p;
+	unsigned int record = 1;
 
 	buf[0] = '\0';
 
@@ -88,7 +89,10 @@
 		args.zone = "e164.arpa";
 
 	if (!args.options)
-		args.options = "1";
+		args.options = "";
+
+	if (args.record)
+		record = atoi(args.record);
 
 	/* strip any '-' signs from number */
 	for (s = p = args.number; *s; s++) {
@@ -100,7 +104,7 @@
 	}
 
 	res = ast_get_enum(chan, num, dest, sizeof(dest), tech, sizeof(tech), args.zone,
-			   args.options);
+			   args.options, record);
 
 	p = strchr(dest, ':');
 	if (p && strcasecmp(tech, "ALL"))
diff -ru asterisk-1.4.0-beta2/include/asterisk/enum.h asterisk-1.4.0-beta2-simple/include/asterisk/enum.h
--- asterisk-1.4.0-beta2/include/asterisk/enum.h	2006-03-31 12:29:50.000000000 +0200
+++ asterisk-1.4.0-beta2-simple/include/asterisk/enum.h	2006-10-16 13:39:45.000000000 +0200
@@ -35,9 +35,11 @@
                        If you need any record, then set it to empty string
 	\param maxtech  Max length
 	\param suffix   Zone suffix (if is NULL then use enum.conf 'search' variable)
-	\param options  Options ('c' to count number of NAPTR RR, or number - the position of required RR in the answer list
+	\param options  Options ('c' to count number of NAPTR RR)
+	\param record   The position of required RR in the answer list
 */
-int ast_get_enum(struct ast_channel *chan, const char *number, char *location, int maxloc, char *technology, int maxtech, char* suffix, char* options);
+int ast_get_enum(struct ast_channel *chan, const char *number, char *location, int maxloc, char *technology, 
+		int maxtech, char* suffix, char* options, unsigned int record);
 
 /*!	\brief Lookup DNS TXT record (used by app TXTCIDnum
 	\param chan	Channel
diff -ru asterisk-1.4.0-beta2/main/enum.c asterisk-1.4.0-beta2-simple/main/enum.c
--- asterisk-1.4.0-beta2/main/enum.c	2006-08-21 04:11:39.000000000 +0200
+++ asterisk-1.4.0-beta2-simple/main/enum.c	2006-10-16 15:51:47.000000000 +0200
@@ -387,7 +387,7 @@
 }
 
 /*! \brief ENUM lookup */
-int ast_get_enum(struct ast_channel *chan, const char *number, char *dst, int dstlen, char *tech, int techlen, char* suffix, char* options)
+int ast_get_enum(struct ast_channel *chan, const char *number, char *dst, int dstlen, char *tech, int techlen, char* suffix, char* options, unsigned int record)
 {
 	struct enum_context context;
 	char tmp[259 + 512];
@@ -412,7 +412,7 @@
 	context.tech = tech;
 	context.techlen = techlen;
 	context.options = 0;
-	context.position = 1;
+	context.position = record;
 	context.naptr_rrs = NULL;
 	context.naptr_rrs_count = 0;
 
@@ -420,13 +420,12 @@
 		if (*options == 'c') {
 			context.options = ENUMLOOKUP_OPTIONS_COUNT;
 			context.position = 0;
-		} else {
-			context.position = atoi(options);
-			if (context.position < 1)
-				context.position = 1;
 		}
 	}
 
+	ast_log(LOG_DEBUG, "ast_get_enum(): n='%s', tech='%s', suffix='%s', options='%d', record='%d'\n",
+			number, tech, suffix, context.options, context.position);
+
 	if (pos > 128)
 		pos = 128;
 
@@ -466,25 +465,34 @@
 	if (chan && ast_autoservice_start(chan) < 0)
 		return -1;
 
-	for (;;) {
-		ast_mutex_lock(&enumlock);
-		if (version != enumver) {
-			/* Ooh, a reload... */
-			s = toplevs;
-			version = enumver;
-		} else {
-			s = s->next;
-		}
-		ast_copy_string(tmp + newpos, suffix ? suffix : s->toplev, sizeof(tmp) - newpos);
-		ast_mutex_unlock(&enumlock);
-		if (!s)
-			break;
+	if(suffix) {
+		ast_copy_string(tmp + newpos, suffix, sizeof(tmp) - newpos);
 		ret = ast_search_dns(&context, tmp, C_IN, T_NAPTR, enum_callback);
-		if (ret > 0)
-			break;
-		if (suffix != NULL)
-			break;
+		ast_log(LOG_DEBUG, "ast_get_enum: ast_search_dns(%s) returned %d\n", tmp, ret);
+	} else {
+		ret = -1;		/* this is actually dead code since the demise of app_enum.c */
+		for (;;) {
+			ast_mutex_lock(&enumlock);
+			if (version != enumver) {
+				/* Ooh, a reload... */
+				s = toplevs;
+				version = enumver;
+			} else {
+				s = s->next;
+			}
+			ast_mutex_unlock(&enumlock);
+
+			if (!s)
+				break;
+	
+			ast_copy_string(tmp + newpos, s->toplev, sizeof(tmp) - newpos);
+			ret = ast_search_dns(&context, tmp, C_IN, T_NAPTR, enum_callback);
+			ast_log(LOG_DEBUG, "ast_get_enum: ast_search_dns(%s) returned %d\n", tmp, ret);
+			if (ret > 0)
+				break;
+		}
 	}
+
 	if (ret < 0) {
 		ast_log(LOG_DEBUG, "No such number found: %s (%s)\n", tmp, strerror(errno));
 		strcpy(dst, "0");
